@@ -2,7 +2,7 @@ from PyQt5.QtWidgets import QWidget, QPushButton, QHBoxLayout, QStackedWidget
 
 from feeluown.gui.widgets.magicbox import MagicBox
 from feeluown.gui.widgets.statusline import StatusLine, StatusLineItem
-from feeluown.gui.widgets.statusline_items import PluginStatus, NotifyStatus
+from feeluown.gui.widgets.statusline_items import NotifyStatus
 
 
 class ToolbarButton(QPushButton):
@@ -26,11 +26,11 @@ class BottomPanel(QWidget):
         self._stack_switch.hide()
 
         self.status_line = StatusLine(self._app)
+        self.toggle_sidebar_btn = ToolbarButton('◨', self)
         self.settings_btn = ToolbarButton('⋮', self)
         self.settings_btn.setToolTip('配置')
 
         # initialize widgets
-        self.status_line.add_item(StatusLineItem('plugin', PluginStatus(self._app)))
         self.status_line.add_item(StatusLineItem('notify', NotifyStatus(self._app)))
         self.back_btn.setEnabled(False)
         self.forward_btn.setEnabled(False)
@@ -55,6 +55,7 @@ class BottomPanel(QWidget):
         # self._layout.addStretch(0)
         self._layout.addSpacing(80)
         self._layout.addWidget(self.status_line)
+        self._layout.addWidget(self.toggle_sidebar_btn)
         self._layout.addWidget(self.settings_btn)
 
         # assume the magicbox height is about 30
